# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/schema.ipynb (unless otherwise specified).

__all__ = [
    "ReformeSocioFiscale",
    "OneSimulationResult",
    "AllSimulationResult",
    "Status",
]

# Cell
from typing import Dict, List, Optional, Union

from pydantic import BaseModel

# Cell


class ReformeSocioFiscale(BaseModel):
    """
    This is the API Input
    :year: Année fiscal du calcul
    :reform: Un dictionnaire des paramètres OpenFisca a modifier
    :output_variables: Les variables OpenFisca que l'on souhaite en sortie
    :quantile_nb: Le nombre de décile souhaités : 4 pour quartile, 10 pour des décile, 100 pour centile,...
    :quantile_base_variable: Variables de base pour les déciles, 'rfr' par exemple.
        Si plusieurs variables, on en fait la somme avant d'en calculer les déciles.
    :quantile_compare_variables: Variables OpenFisca que l'on souhaite dans les déciles, 'csg' par exemple.
        On n'en calcul pas les déciles, on récupère
    """

    base: int
    plf: Optional[int]
    amendement: Optional[Dict[str, Union[float, int, str, Dict]]]
    # amendement: Optional[Dict[str, Union[float, int, str]]]  # TODO: Ne fonctionne pas !!!
    output_variables: List[str]
    quantile_nb: int = 0
    quantile_base_variable: Optional[List[str]]
    quantile_compare_variables: Optional[List[str]]

    class Config:
        schema_extra = {
            "example": {
                "base": 2021,
                "plf": 2022,
                "amendement": {
                    "prelevements_sociaux.contributions_sociales.csg.activite.deductible.taux": {
                        "start": "2022-01-01",
                        "type": "parameter",
                        "value": 0.068,
                    },
                    "prelevements_sociaux.contributions_sociales.csg.activite.imposable.abattement": {
                        "scale": [
                            {"rate": {"value": 0.0175}, "threshold": {"value": 0}},
                            {"rate": {"value": 0}, "threshold": {"value": 4}},
                        ],
                        "start": "2022-01-01",
                        "type": "scale",
                    },
                },
                "output_variables": [
                    "assiette_csg_abattue",
                    "csg_imposable_salaire",
                    "csg_deductible_salaire",
                ],
                "quantile_nb": 10,
                "quantile_base_variable": [
                    "assiette_csg_abattue",
                ],
                "quantile_compare_variables": [
                    "csg_imposable_salaire",
                    "csg_deductible_salaire",
                ],
            }
        }


# Cell


class OneSimulationResult(BaseModel):
    """
    This is the output for one simulation
    """

    # Le budget de l'Etat est une liste de variables OpenFisca avec un montant
    state_budget: Dict[str, float]
    quantiles: Optional[List[Dict[str, float]]]

    class Config:
        schema_extra = {
            "example": {
                "result": {
                    "base": {
                        "state_budget": {
                            "assiette_csg_abattue": 707659989877.222,
                            "csg_imposable_salaire": 18946434417.53509,
                            "csg_deductible_salaire": 53681564118.882835,
                        },
                        "quantiles": [
                            {
                                "fraction": 0.1,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.2,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.30000000000000004,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.4,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.5,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.6000000000000001,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.7000000000000001,
                                "assiette_csg_abattue": 1.0,
                                "csg_imposable_salaire": 64.21442413330078,
                                "csg_deductible_salaire": 181.94085693359375,
                                "csg_imposable_salaire+csg_deductible_salaire": 246.15528106689453,
                            },
                            {
                                "fraction": 0.8,
                                "assiette_csg_abattue": 15000.0,
                                "csg_imposable_salaire": 4550290.0,
                                "csg_deductible_salaire": 12892489.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 17442779.0,
                            },
                            {
                                "fraction": 0.9,
                                "assiette_csg_abattue": 38000.0,
                                "csg_imposable_salaire": 23976136.0,
                                "csg_deductible_salaire": 67932384.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 91908520.0,
                            },
                            {
                                "fraction": 1.0,
                                "assiette_csg_abattue": 2430000.0,
                                "csg_imposable_salaire": 64607132.0,
                                "csg_deductible_salaire": 183053552.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 247660684.0,
                            },
                        ],
                    },
                    "plf": {
                        "state_budget": {
                            "assiette_csg_abattue": 707685530919.9353,
                            "assiette_csg_non_abattue": 901955117.2580588,
                            "csg_imposable_salaire": 18948632290.6138,
                            "csg_deductible_salaire": 53687791481.344246,
                        },
                        "quantiles": [
                            {
                                "fraction": 0.1,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.2,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.30000000000000004,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.4,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.5,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.6000000000000001,
                                "assiette_csg_abattue": 0.0,
                                "csg_imposable_salaire": 0.0,
                                "csg_deductible_salaire": 0.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 0.0,
                            },
                            {
                                "fraction": 0.7000000000000001,
                                "assiette_csg_abattue": 1.0,
                                "csg_imposable_salaire": 63.25267028808594,
                                "csg_deductible_salaire": 179.2158966064453,
                                "csg_imposable_salaire+csg_deductible_salaire": 242.46856689453125,
                            },
                            {
                                "fraction": 0.8,
                                "assiette_csg_abattue": 15000.0,
                                "csg_imposable_salaire": 4557889.5,
                                "csg_deductible_salaire": 12914021.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 17471910.5,
                            },
                            {
                                "fraction": 0.9,
                                "assiette_csg_abattue": 38000.0,
                                "csg_imposable_salaire": 23977288.0,
                                "csg_deductible_salaire": 67935656.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 91912944.0,
                            },
                            {
                                "fraction": 1.0,
                                "assiette_csg_abattue": 2450000.0,
                                "csg_imposable_salaire": 64607856.0,
                                "csg_deductible_salaire": 183055600.0,
                                "csg_imposable_salaire+csg_deductible_salaire": 247663456.0,
                            },
                        ],
                    },
                    "amendement": {
                        "state_budget": {
                            "assiette_csg_abattue": 707685530919.9353,
                            "assiette_csg_non_abattue": 901955117.2580588,
                            "csg_imposable_salaire": 19834385617.186886,
                            "csg_deductible_salaire": 56197425909.127014,
                        },
                        "quantiles": [
                            {
                                "fraction": 0.1,
                                "count": 10264.0,
                                "assiette_csg_abattue": 490.0,
                                "csg_imposable_salaire": 2247949.095769886,
                                "csg_deductible_salaire": 6369189.109860641,
                                "csg_imposable_salaire+csg_deductible_salaire": 8617138.205630526,
                            },
                            {
                                "fraction": 0.2,
                                "count": 10263.0,
                                "assiette_csg_abattue": 4700.0,
                                "csg_imposable_salaire": 118169473.33539566,
                                "csg_deductible_salaire": 334813507.04539794,
                                "csg_imposable_salaire+csg_deductible_salaire": 452982980.3807936,
                            },
                            {
                                "fraction": 0.30000000000000004,
                                "count": 10263.0,
                                "assiette_csg_abattue": 12000.0,
                                "csg_imposable_salaire": 487096637.9451813,
                                "csg_deductible_salaire": 1380107145.4939938,
                                "csg_imposable_salaire+csg_deductible_salaire": 1867203783.4391751,
                            },
                            {
                                "fraction": 0.4,
                                "count": 10264.0,
                                "assiette_csg_abattue": 19000.0,
                                "csg_imposable_salaire": 941617774.6512764,
                                "csg_deductible_salaire": 2667917025.4034853,
                                "csg_imposable_salaire+csg_deductible_salaire": 3609534800.054762,
                            },
                            {
                                "fraction": 0.5,
                                "count": 10263.0,
                                "assiette_csg_abattue": 25000.0,
                                "csg_imposable_salaire": 1334142360.6361191,
                                "csg_deductible_salaire": 3780070027.193918,
                                "csg_imposable_salaire+csg_deductible_salaire": 5114212387.830037,
                            },
                            {
                                "fraction": 0.6000000000000001,
                                "count": 10263.0,
                                "assiette_csg_abattue": 32000.0,
                                "csg_imposable_salaire": 1693595612.6919947,
                                "csg_deductible_salaire": 4798520898.489887,
                                "csg_imposable_salaire+csg_deductible_salaire": 6492116511.181882,
                            },
                            {
                                "fraction": 0.7000000000000001,
                                "count": 10264.0,
                                "assiette_csg_abattue": 41000.0,
                                "csg_imposable_salaire": 2150292953.202396,
                                "csg_deductible_salaire": 6092496696.606046,
                                "csg_imposable_salaire+csg_deductible_salaire": 8242789649.808441,
                            },
                            {
                                "fraction": 0.8,
                                "count": 10263.0,
                                "assiette_csg_abattue": 53000.0,
                                "csg_imposable_salaire": 2787016111.039954,
                                "csg_deductible_salaire": 7896545647.109608,
                                "csg_imposable_salaire+csg_deductible_salaire": 10683561758.149563,
                            },
                            {
                                "fraction": 0.9,
                                "count": 10263.0,
                                "assiette_csg_abattue": 74000.0,
                                "csg_imposable_salaire": 3649594506.051685,
                                "csg_deductible_salaire": 10340517762.183483,
                                "csg_imposable_salaire+csg_deductible_salaire": 13990112268.235168,
                            },
                            {
                                "fraction": 1.0,
                                "count": 10263.0,
                                "assiette_csg_abattue": 2450000.0,
                                "csg_imposable_salaire": 6670612238.537115,
                                "csg_deductible_salaire": 18900068010.49135,
                                "csg_imposable_salaire+csg_deductible_salaire": 25570680249.028465,
                            },
                        ],
                    },
                },
                "errors": [
                    "We do not have a correction factor for assiette_csg_abattue",
                    "We do not have a correction factor for assiette_csg_non_abattue",
                ],
            }
        }


class AllSimulationResult(BaseModel):
    """
    This is the API Output for all simulations
    """

    result: Optional[Dict[str, OneSimulationResult]]
    errors: Optional[List[str]]

    class Config:
        schema_extra = {
            "example": {
                "result": {
                    "base": {
                        "state_budget": {"csg": -149632194907.95862},
                        "quantiles": [
                            {
                                "fraction": 0.25,
                                "rfr": 6512651.196820104,
                                "csg": -1587618.1703133795,
                            },
                            {
                                "fraction": 0.5,
                                "rfr": 13752027.51171984,
                                "csg": -339520.6368227325,
                            },
                            {
                                "fraction": 0.75,
                                "rfr": 25330039.64568395,
                                "csg": 0.0,
                            },
                            {"fraction": 1.0, "rfr": 7781726526.500929, "csg": 0.0},
                        ],
                    },
                    "plf": {
                        "state_budget": {"csg": -149632194907.95862},
                        "quantiles": [
                            {
                                "fraction": 0.25,
                                "rfr": 6512651.196820104,
                                "csg": -1587618.1703133795,
                            },
                            {
                                "fraction": 0.5,
                                "rfr": 13752027.51171984,
                                "csg": -339520.6368227325,
                            },
                            {
                                "fraction": 0.75,
                                "rfr": 25330039.64568395,
                                "csg": 0.0,
                            },
                            {"fraction": 1.0, "rfr": 7781726526.500929, "csg": 0.0},
                        ],
                    },
                }
            }
        }


# Cell


class Status(BaseModel):
    """
    This returns the status of the current projet
    """

    cache: bool
    simulations: bool
    version_openfisca: List[str]
    last_commit: str

    class Config:
        schema_extra = {
            "example": {
                "cache": True,
                "simulations": True,
                "version_openfisca": ["openfisca-france", "76.1.0"],
                "last_commit": "14c6ae",
            }
        }
